@@ -1,5 +1,5 @@
-from typing import Any, Dict
+from typing import Any
 
 #: A precise expectation of what mappings looks like in json.
 #: (dict where keys are always of type `str`).
-JSONType = Dict[str, Any]
+JSONType = dict[str, Any]
